summaryrefslogtreecommitdiff
path: root/gcc/dse.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/dse.c')
-rw-r--r--gcc/dse.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/gcc/dse.c b/gcc/dse.c
index 9d19b7071ee..6984e19bd95 100644
--- a/gcc/dse.c
+++ b/gcc/dse.c
@@ -531,7 +531,7 @@ struct clear_alias_mode_holder
static alloc_pool clear_alias_mode_pool;
/* This is true except if current_function_stdarg -- i.e. we cannot do
this for vararg functions because they play games with the frame. */
static bool stores_off_frame_dead_at_return;
@@ -718,7 +718,7 @@ dse_step0 (void)
bb_table = XCNEWVEC (bb_info_t, last_basic_block);
rtx_group_next_id = 0;
- stores_off_frame_dead_at_return = !current_function_stdarg;
+ stores_off_frame_dead_at_return = !cfun->stdarg;
init_alias_analysis ();
@@ -2163,7 +2163,7 @@ dse_step1 (void)
&& (EDGE_COUNT (bb->succs) == 0
|| (single_succ_p (bb)
&& single_succ (bb) == EXIT_BLOCK_PTR
- && ! current_function_calls_eh_return)))
+ && ! crtl->calls_eh_return)))
{
insn_info_t i_ptr = active_local_stores;
while (i_ptr)
@@ -531,7 +531,7 @@ struct clear_alias_mode_holder
static alloc_pool clear_alias_mode_pool;
-/* This is true except if current_function_stdarg -- i.e. we cannot do
+/* This is true except if cfun->stdarg -- i.e. we cannot do
this for vararg functions because they play games with the frame. */
static bool stores_off_frame_dead_at_return;